==> rucy-0.1.0.tar.gz: rucy-0.1.0/lib_wpm/wpm/cgidriver.rb <==
# $Id: cgidriver.rb,v 1.1.1.1 2004/04/04 15:22:50 toki Exp $
# -
# HTTP message driver for cgi.rb

require 'cgi'

module WPM
  class CGIDriver < Driver
    def initialize
      @cgi = CGI.new
      @options = Hash.new
      @messg_body = ''
      @closed = false
    end

    def handler
      @closed and raise 'closed'
      @cgi
    end

    def env
      @closed and raise 'closed'
      ENV
    end

    def params
      @closed and raise 'closed'

      params = Hash.new
      for name in @cgi.keys
	params[name] = @cgi[name].first.to_s
      end

      params
    end

    def header(name)
      @closed and raise 'closed'

      case (name)
      when /^Content-Type$/i
	content_type = @options['type']
	content_type += '; charset=' + @options['charset'] if (@options.include? 'charset')
	return content_type
      when /^Status$/i
	return @options['status']
      when /^Server$/i
	return @options['server']
      when /^Connection$/i
	return @options['connection']
      when /^Content-Length$/i
	return @options['length']
      when /^Content-Language$/i
	return @options['language']
      when /^Expires$/i
	return @options['expires']
      when /^Set-Cookie$/i
	return @options['cookie']
      else
	return @options[name]
      end
    end

    def set_header(name, value)
      @closed and raise 'closed'

      case (name)
      when /^Content-Type$/i
	if (value =~ %r"^\S+/\S+") then
	  @options['type'] = $&
	  @options['type'].gsub!(/;$/, '')
	end
	if (value =~ %r'charset="([^"]+)"' || value =~ %r"charset=(\S+)") then
	  @options['charset'] = $1
	end
      when /^Status$/i
	@options['status'] = value
      when /^Server$/i
	@options['server'] = value
      when /^Connection$/i
	@options['connection'] = value
      when /^Content-Length$/i
	@options['length'] = value
      when /^Content-Language$/i
	@options['language'] = value
      when /^Expires$/i
	@options['expires'] = value
      when /^Set-Cookie$/i
	@options['cookie'] = value
      else
	@options[name] = value
      end

      nil
    end

    def write(messg_body)
      @closed and raise 'closed'
      @messg_body.concat(messg_body)
      nil
    end

    def close
      @closed and raise 'closed'
      @closed = true
      @cgi.out(@options) { @messg_body }
      nil
    end
  end
end

==> rucy-0.5.0.tar.gz: rucy-0.5.0/lib_wpm/wpm/cgidriver.rb <==
# $Id: cgidriver.rb,v 1.4 2005/06/16 14:04:06 toki Exp $
# -
# HTTP message driver for cgi.rb

=begin
# example

require 'wpm'
require 'wpm/rexml'
require 'wpm/cgidriver'

writer = WPM::Writer.new(WPM::XMLAssistByREXML)
writer.run(WPM::CGIDriver.new)
=end

require 'cgi'

module WPM
  class CGIDriver < Driver
    def initialize(cgi=CGI.new)
      @cgi = cgi
      @options = Hash.new
      @messg_body = ''
      @closed = false
    end

    def handler
      @closed and raise 'closed'
      @cgi
    end

    def env
      @closed and raise 'closed'
      ENV
    end

    def params
      @closed and raise 'closed'

      params = Hash.new
      for name in @cgi.keys
	params[name] = @cgi.params[name].first.to_s
      end

      params
    end

    def header(name)
      @closed and raise 'closed'

      case (name.upcase)
      when 'CONTENT-TYPE'
	content_type = @options['type']
	content_type += '; charset=' + @options['charset'] if (@options.include? 'charset')
	return content_type
      when 'STATUS'
	return @options['status']
      when 'SERVER'
	return @options['server']
      when 'CONNECTION'
	return @options['connection']
      when 'CONTENT-LENGTH'
	return @options['length']
      when 'CONTENT-LANGUAGE'
	return @options['language']
      when 'EXPIRES'
	return @options['expires']
      when 'SET-COOKIE'
	return @options['cookie']
      else
	return @options[name]
      end
    end

    def set_header(name, value)
      @closed and raise 'closed'

      case (name.upcase)
      when 'CONTENT-TYPE'
	if (value =~ %r"^\S+/\S+") then
	  @options['type'] = $&
	  @options['type'].gsub!(/;$/, '')
	end
	if (value =~ %r'charset="([^"]+)"' || value =~ %r"charset=(\S+)") then
	  @options['charset'] = $1
	end
      when 'STATUS'
	@options['status'] = value
      when 'SERVER'
	@options['server'] = value
      when 'CONNECTION'
	@options['connection'] = value
      when 'CONTENT-LENGTH'
	@options['length'] = value
      when 'CONTENT-LANGUAGE'
	@options['language'] = value
      when 'EXPIRES'
	@options['expires'] = value
      when 'SET-COOKIE'
	@options['cookie'] = value
      else
	@options[name] = value
      end

      nil
    end

    def write(messg_body)
      @closed and raise 'closed'
      @messg_body.concat(messg_body)
      nil
    end

    def close
      @closed and raise 'closed'
      @closed = true
      @cgi.out(@options) { @messg_body }
      nil
    end
  end
end
